## =============================================================================
## Requirements
## =============================================================================

source("function_trans_cols.R")

if (trans_vars==TRUE){
  # If trans_vars flag is TRUE, transform specified variables
  dta<-trans_cols(dta_backup,sqrts=sqrt_vars,log1ps = log1p_vars_all)
} else {dta<-dta_backup}

library(dplyr)
library(gtsummary)

source("function_back_trans.R")

## =============================================================================
## Regression tables
## =============================================================================

dta_l<-dta|>
  dplyr::select(all_of(c(vars,outs))) # active_treat should be vector

sel<-dta_l|>
  sapply(is.factor)

## Bivariate
biv<-dta_l|>
  tbl_uvregression(data=_,
                   y=outs,
                   method=lm,
                   label = lab_sel(labels_all,vars),
                   show_single_row=colnames(dta_l)[sel],
                   estimate_fun = ~style_sigfig(.x,digits = 3),
                   pvalue_fun = ~style_pvalue(.x, digits = 3)
  )  |> 
  add_global_p()|>
  bold_p()

## Multivariate
mul<-dta_l |>
  lm(nihss_0~pase_0+., 
     data = _) |> 
  tbl_regression(show_single_row=colnames(dta_l)[sel],
                 estimate_fun = ~style_sigfig(.x,digits = 3),
                 pvalue_fun = ~style_pvalue(.x, digits = 3),
                 label = lab_sel(labels_all,vars)
  )|> 
  add_n() |>
  add_global_p() |>
  bold_p() |>  
  bold_labels() |>
  italicize_levels()

# Back transforming if flag set
if (trans_back==TRUE){
  ls<-lapply(list(biv,mul), back_trans, outm = "log1p" ,sqrts = sqrt_vars)
} else {ls<-list(biv,mul)}


## =============================================================================
## Merge
## =============================================================================

if (trans_back==TRUE){tab_span<-c("**Bivariate linear regression [TRANS t/r]**", 
                                  "**Multivariate linear regression [TRANS t/r]**")
} else {tab_span<-c("**Bivariate linear regression**", 
                    "**Multivariate linear regression**")}

bm_16_tbl<-tbl_merge(
  tbls = ls, 
  tab_spanner = tab_span 
)

## =============================================================================
## Print
## =============================================================================

# File name depending onstratification, transformation and back transformation
if (print_tbl==TRUE){
  fnm<-paste0("bm_16_tbl",lbl_x)
  if (!is.null(strat_var)){fnm<-paste0(fnm,"_strat")}
  if (trans_vars==TRUE){fnm<-paste0(fnm,"_trans")}
  if (trans_back==TRUE){fnm<-paste0(fnm,"_back")}
  
  
  bm_16_tbl_rtf <- file(paste0(fnm,".RTF"), "w")
  writeLines(bm_16_tbl%>%as_gt()%>%as_rtf(), bm_16_tbl_rtf)
  close(bm_16_tbl_rtf)
  
}